@@ -397,10 +397,7 @@ def _get_schedule_rejected_comments(event_info):
     return None
 
 def get_status_info(delivery_order):
-    events_info = None
-    status = None
-    description = None
-    last_event_timestamp = None
+    events_info, status, description, last_event_timestamp = None, None, None, None
 
     if delivery_order['status'] == DeliveryOrderStatusType.Planning.value:
         events_info = filter(
@@ -538,7 +535,7 @@ def get_status_info(delivery_order):
         description_dic = get_delivery_order_status_description_dic()
         description = description_dic[delivery_order['status']]
 
-    elif DeliveryOrderStatusType.Delivered.value in delivery_order['statuses']:
+    elif DeliveryOrderStatusType.Delivered.value == DeliveryOrderStatusType.Delivered.value:
         events_info = filter(
             lambda x: x['status'] == DeliveryOrderStatusType.Delivered.value,
             delivery_order['events_info']
@@ -546,16 +543,6 @@ def get_status_info(delivery_order):
         status = 'Entregado'
         description = 'Entrega realizada'
 
-    elif delivery_order['status'] == DeliveryOrderStatusType.DeliveryRejected.value:
-        events_info = filter(
-            lambda x: x['status'] == delivery_order['status'],
-            delivery_order['events_info']
-        )
-        status = 'Entrega Rechazada'
-        description = _get_schedule_rejected_comments(events_info[len(events_info) - 1]['info']) if \
-            _get_schedule_rejected_comments(events_info[len(events_info) - 1]['info']) is not None \
-            else "Entrega Rechazada"
-
     elif delivery_order['status'] in DELIVERY_ORDER_REJECTED_STATUSES:
         events_info = filter(
             lambda x: x['status'] == delivery_order['status'],
